#include <Adafruit_NeoPixel.h>
#include "pitches.h"

#define BUZZER_PIN 38
#define LED_PIN    35
#define NUM_LEDS   1
#define BRIGHTNESS 100

Adafruit_NeoPixel strip = Adafruit_NeoPixel(NUM_LEDS, LED_PIN, NEO_GRB + NEO_KHZ800);

// Define the Super Mario Bros melody
int melody[] = {
  NOTE_E7, NOTE_E7, 0, NOTE_E7, 0, NOTE_C7, NOTE_E7, 0, NOTE_G7, 0, 0, 0, NOTE_G6, 0, 0, 0,
  NOTE_C7, 0, 0, NOTE_G6, 0, 0, NOTE_E6, 0, NOTE_A6, 0, NOTE_B6, 0, NOTE_AS6, NOTE_A6, 0,
  NOTE_G6, NOTE_E7, NOTE_G7, NOTE_A7, 0, NOTE_F7, NOTE_G7, 0, NOTE_E7, 0, NOTE_C7, NOTE_D7, NOTE_B6, 0,
  NOTE_C7, 0, 0, NOTE_G6, 0, 0, NOTE_E6, 0, NOTE_A6, 0, NOTE_B6, 0, NOTE_AS6, NOTE_A6, 0,
  NOTE_G6, NOTE_E7, NOTE_G7, NOTE_A7, 0, NOTE_F7, NOTE_G7, 0, NOTE_E7, 0, NOTE_C7, NOTE_D7, NOTE_B6, 0
};

int noteDurations[] = {
  12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
  12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
  12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
  12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
  12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12
};

void setup() {
  strip.begin();
  strip.setBrightness(BRIGHTNESS); // Установите яркость
  strip.show(); // Initialize all pixels to 'off'

  pinMode(BUZZER_PIN, OUTPUT);
}

void loop() {
  for (int thisNote = 0; thisNote < sizeof(melody) / sizeof(melody[0]); thisNote++) {
    // Calculate the note duration
    int noteDuration = 1000 / noteDurations[thisNote];

    // Play the note
    if (melody[thisNote] != 0) {
      tone(BUZZER_PIN, melody[thisNote], noteDuration);
    }

    // Set LED color based on the current note
    switch (thisNote % 3) {
      case 0:
        strip.setPixelColor(0, strip.Color(255, 0, 0)); // Red
        break;
      case 1:
        strip.setPixelColor(0, strip.Color(0, 255, 0)); // Green
        break;
      case 2:
        strip.setPixelColor(0, strip.Color(0, 0, 255)); // Blue
        break;
    }
    strip.show();

    // Delay for the note duration plus a short pause
    delay(noteDuration * 1.30);

    // Stop the tone playing
    noTone(BUZZER_PIN);
  }

  // Turn off the LED after the melody is played
  strip.setPixelColor(0, strip.Color(0, 0, 0)); // Off
  strip.show();

  // Delay before playing the melody again
  delay(2000);
}
